#!/usr/local/bin/artclsh

	global list result network_meas nwa dac adc ltc lcr keithley tektronix;
	
	source network_meas.data;
	
	if {[file exists [Exp_Config_Dir]/flags/network_meas.parameters]} {
		puts "reading external parameters ..."
		source [Exp_Config_Dir]/flags/network_meas.parameters
		file delete [Exp_Config_Dir]/flags/network_meas.parameters
	}

    set list(network_meas:soll) [lindex [ValIn $network_meas(period)] 0]	
	set network_meas(basename) "$network_meas(month)[]d$network_meas(number)"
	set network_meas(prefix) "../data/microwave/mw$network_meas(basename)"

	set network_meas(1:start) 8.5e9
	set network_meas(1:stop) 11.0e9
	set network_meas(2:start) $network_meas(1:stop)
	set network_meas(2:stop) 13.5e9
	set network_meas(q_max) 15000
	set network_meas(q_min) 50
	set network_meas(trans_max) -55
	set network_meas(trans_min) -62
	set network_meas(1:frequency_width) "5MHz"
	set network_meas(2:frequency_width) "20MHz"
	
	set network_meas(recordspectrum) 0
	set network_meas(test_filament) 0
	set network_meas(nodataoutput) 0
	set tektronix(use) 0
	set lcr(use) 1
	
	set nwa(address) "HP8719D"
	set nwa(channels) "1"
	set nwa(numpoints) 401
	set nwa(numpoints_nolock) 1601
	set network_meas(filament) 1
	set network_meas(nextpuls) "puls: off"
	set result(nextpuls) "0 0 0"
	
	set dac(number) 2
	set dac(maxevents) 100

	set adc(ch:fil_current) 12
	set adc(ch:fil_voltage) 13
	set adc(ch:pressure) 14
	set adc(ch:baratron) 15
	
	set ltc(address) "LTC10"
	set ltc(upper_temp2)	40000
	set ltc(lower_temp2)	30000
	
	set lcr(address) "HP4284A"
	
	set keithley(address) "K2000"

	set tektronix(address) "TDS210"

proc writedata {} {
	global network_meas

	set datafile [open "~eminus/ar/network_meas.data" w]
	puts $datafile "set network_meas(month) \"$network_meas(month)\""
	puts $datafile "set network_meas(number) \"$network_meas(number)\""
	puts $datafile "set network_meas(section) \"$network_meas(section)\""
	puts $datafile "set network_meas(period) \"$network_meas(period)\""
	puts $datafile "set network_meas(power) \"$network_meas(power)\""
	close $datafile
}
proc init_measurement {} {
	global list network_meas result nwa lcr tektronix;

	if {![file exists "$network_meas(prefix)"]} {
		puts "making directory \"$network_meas(prefix)\""
		exec ln --force -s $network_meas(prefix)/mw$network_meas(basename)[].dat network_meas.datafile
		file mkdir "$network_meas(prefix)"	
		set list(network_meas:count) 1
		status write network_meas.s0 "0"
		status write [Exp_Config_Dir]/params/fil_puls.s0 "stop 0V 0ms 0s"
	}
	
	if {![info exists list(network_meas:init)]} {
		puts "init ..."
		if {$tektronix(use)} {
			puts "using TDS210"		
			ieee write $tektronix(address) "acq:stopa seq"
		}
	
	ieee read $nwa(address)
		
		if {[llength $nwa(channels)] == 2} {
			ieee write $nwa(address) "COUCOFF;SPLDON;DUACON;"
		} else {
			ieee write $nwa(address) "COUCOFF;SPLDOFF;DUACOFF;"
		}
		
		foreach ch $nwa(channels) {
			ieee write $nwa(address) "CHAN$ch;S21;STAR$network_meas($ch:start);STOP$network_meas($ch:stop);POIN$nwa(numpoints_nolock);POWE$network_meas(power);"
			set list(network_meas:$ch:locked) 0
		}
	
		if {$lcr(use)} {
			puts "using LCR-Meter"
#ieee write $lcr(address) "A2;B3;C1;D0;F21;H1;R13;T1;"
		}

		set list(network_meas:init) 1
	}
	
	if {![info exists list(network_meas:watch_temp2)]} {
		# Falls die Variable list(network_meas:watch_temp2) nicht
		# existiert, diese auf 0 setzen
		set list(network_meas:watch_temp2) 0
	}

	set result(filament1) "?"
	set result(filament2) "?"
	set result(U_clamp) "?"
	set result(baratron) "?"
	set result(silicon) "?"

}

proc switch_filament_to_ohmmeter {} {
	global network_meas;

	dout clear 4
	
	if {$network_meas(filament) != 1} {
		dout clear 3
	} else { 
		dout set 3
	}	
}

proc trigger_nwa {} {
	global nwa list network_meas
	# Netzwerkanalysator triggern	
	foreach ch $nwa(channels) {
		if {$list(network_meas:$ch:locked)} { 
			ieee write $nwa(address) "CHAN$ch;POIN$nwa(numpoints);POWE$network_meas(power);SING;"
		} else {
			ieee write $nwa(address) "CHAN$ch;STAR$network_meas($ch:start);STOP$network_meas($ch:stop);POIN$nwa(numpoints_nolock);POWE$network_meas(power);SING;"
		}
	}
}

proc readout_old {} {
	global keithley result
	
	set result(frequency) "?"
	if {[scan [kscan select $keithley(address) MW_FreqOffset] "%f" result(frequency)]!=1} {
		set result(frequency) "?"
	}
	
	set result(amplitude) "?"
	if {[scan [kscan select $keithley(address) MW_Amplitude] "%f" result(amplitude)]!=1} {
		set result(amplitude) "?"
	}
	
	set result(nwa) "$result(amplitude) $result(frequency)"
}

proc readout_capacity {} {
	global lcr result
		
	set result(cap) "?"
	set result(G) "?"
	if {$lcr(use)} {
# 		if {[ scan [ieee read $lcr(address)] " PRNC%f,NG%f" result(cap) result(G)]!=2} 
 		if {[ scan [ieee query $lcr(address) "fetch?"] "%f,%f,%*f" result(cap) result(G)]!=2} {
			set result(cap) "?"
			set resutt(G) "?"
		} else {
			if {$result(cap) != "?" && $result(cap) < 1e-12} {
				set result(cap) "?"
				set resutt(G) "?"
			}
		}
	}
}

proc readout_filament_data {} {
	global adc result
		
	set result(fil_voltage) [format "%0.3f" [adc read $adc(ch:fil_voltage)]]
	set result(fil_current) [format "%0.5f" [expr 0.1*[adc read $adc(ch:fil_current)]]]
}

proc readout_pressure {} {
	global adc result
	set result(pressure) [adc read $adc(ch:pressure)]
	if {$result(pressure)<0.04 || $result(pressure)>9.99} {
		set result(pressure) ?
	} else {
		set result(pressure) [format "%0.3f" $result(pressure)]
	}
	
	set result(baratron) [expr ([adc read $adc(ch:baratron)])]
	if {$result(baratron)>9.8} {
		if {$result(pressure)<0.2} {
			set result(pressure) "?"
		}
		set result(baratron) "?"
	} else {
		set result(baratron) [format "%0.3f" $result(baratron)]
	}
}

proc readout_temperature {} {
	global list ltc result
	set result(temp1) [string tolower [ieee query $ltc(address) "QSAMP?1;"]]
	set result(temp2) [string tolower [ieee query $ltc(address) "QSAMP?2;"]]

	if {$result(temp1)!= ""} {
		if {[scan [ValIn $result(temp1)] "%f" result(temp1)]!=1} {
			set result(temp1) "?"
		}
	} else {
		set result(temp1) "?"
	}
	
	if {$result(temp2)!=""} {
		if {[scan [ValIn $result(temp2)] "%f" result(temp2)]!=1} {
			set result(temp2) "?"
		}
	} else {
		set result(temp1) "?"
		set result(temp2) "?"
	}
	
	if {$result(temp1) != "?" && $result(temp1)>200 && $result(temp1)<150000} {
		set result(temp1) [format "%0.1f" $result(temp1)]
	} else {
		set result(temp1) "?"
		set result(temp2) "?"
	}

	if {$result(temp2) != "?"} {
		set result(temp2) [format "%0.1f" $result(temp2)]
			
		if {!$list(network_meas:watch_temp2) && $result(temp2) > $ltc(upper_temp2)} {
			set list(network_meas:watch_temp2) 1
			puts "watching temperature drop!"
		}
		
		if {$list(network_meas:watch_temp2) && $result(temp2) < $ltc(lower_temp2)} {
			puts "sending high temperature warning!"
			set fp [open "|mail eminus@gmx.de -s \"high temp warning\"" w]
			puts -nonewline $fp "[datestamp] "
			if {$result(temp1)!="?"} {puts -nonewline $fp "T1=[ValOut $result(temp1)]Ohm "}
			if {$result(temp2)!="?"} {puts -nonewline $fp "T2=[ValOut $result(temp2)]Ohm "}
			if {$result(cap)!="?"} {puts -nonewline $fp "C=[ValOut $result(cap)]F "}
			close $fp
			set list(network_meas:watch_temp2) 0
		}
	} 
}

proc readout_magnet_data {} {
	global keithley result;

	if {[scan [kscan select $keithley(address) Magnet_U] "%f" result(coil_voltage)]==1} {
		if {$result(coil_voltage)==9.9e37} {
			set result(coil_voltage) "?"
		} else {
			set result(coil_voltage) [format "%0.4e" $result(coil_voltage)]
		}
	} else {
		set result(coil_voltage) "?"
	}
		
	
	if {[scan [kscan select $keithley(address) Magnet_I] "%f" result(coil_current)]==1} {
		if {$result(coil_current)==9.9e37} {
			set result(coil_current) "?"
		} else {
			set result(coil_current) [format "%0.4e" [expr 10*$result(coil_current)]]
		}
	} else {
		set result(coil_current) "?"
	}
}

proc readout_silicon_resistance {} {
	global keithley result;
	
	# Werte aus Keithley auslesen ...
	if {$result(temp1) != "?" && $result(temp2) < 3000} {
	
		# auf den Keythley-Eingang umschalten 
		dout set 1
	
		# jetzt den Siliziumwiderstand bestimmen
		if {[scan [kscan select $keithley(address) silicon] "%f" result(silicon)]==1} {
			if {$result(silicon)==9.9e37} {
				set result(silicon) "?"
			}
		} else {
			set result(silicon) "?"
		}
					
		dout clear 1
		
	} else {
		set result(silicon) "?"
	}
}

proc readout_filament1 {} {
	global keithley result;
	if {[scan [kscan select $keithley(address) filament] "%f" result(filament1)]==1} {
		if {$result(filament1)==9.9e37 || $result(filament1)<2 || $result(filament1)>50} {
			set result(filament1) "?"
		} else {
			set result(filament1) [format "%0.3f" $result(filament1)]
		}
	} else {
		set result(filamnent1) "?"
	}
}

proc switch_to_filament1 {} {
	# auf Filament 1 umschalten
	dout clear 3
}

proc switch_to_filament2 {} {
	# auf Filament 2 umschalten
	dout set 3
}

proc readout_filament2 {} {
	global keithley result;
	if {[scan [kscan select $keithley(address) filament] "%f" result(filament2)]==1} {
		if {$result(filament2)==9.9e37 || $result(filament2)<2 || $result(filament2)>50} {
			set result(filament2) "?"
		} else {
			set result(filament2) [format "%0.3f" $result(filament2)]
		}
	} else {
		set result(filament2) "?"
	}
}

proc switch_filament_to_pulsesource {} {
	global network_meas
	if {$network_meas(filament) == 1} { 
		dout clear 3
	} else {
		dout set 3
	}
	
	dout set 4
}

proc prepare_tektronix {} {
	global list dac network_meas tektronix result;
	
	scan [status read fil_puls.s0] "%s %s %s %fs" puls_stat puls_amplitude puls_time puls_repeat
	if {$puls_stat=="puls"} {
		set puls_dt [lindex [ValIn $puls_time] 0]		
			
		if {$tektronix(use)} {
			ieee write $tektronix(address) "acq:state run"
			ieee write $tektronix(address) "hor:main:sca [expr $puls_dt/8]"
			set puls_sca [string trim [ieee query $tektronix(address) "hor:main:sca?"]]
			ieee write $tektronix(address) "hor:main:pos [expr 5*$puls_sca]"
		}
	}
}

proc pulse_filament {} {
	global list dac network_meas tektronix result;

	scan [status read fil_puls.s0] "%s %s %s %fs" puls_stat puls_amplitude puls_time puls_repeat

	if {$puls_stat=="puls"} {
		set puls_dt [lindex [ValIn $puls_time] 0]		
			
		if {$tektronix(use)} {
			after 200
		}

		if {$puls_repeat>0} {
			set number_of_pulses [expr floor(($list(network_meas:soll)-4)/$puls_repeat)-1]
		} else {
			set number_of_pulses 1
		}
		set pulsstring "dac prog $dac(number)"
		set puls_delay "[expr $puls_repeat-[lindex [ValIn $puls_time] 0]]s"
	
		set result(nextpuls) "$puls_amplitude $puls_time $number_of_pulses"
		set network_meas(nextpuls) "puls: $puls_amplitude $puls_time ($number_of_pulses times every $puls_delay)"

		if {$number_of_pulses<=0} {
			set number_of_pulses 1
		}

		if {$number_of_pulses>0} {
			for {set i 0} {$i < $number_of_pulses} {incr i} {
				if {$i !=0} {
					set pulsstring "$pulsstring $puls_delay"
				}
				set pulsstring "$pulsstring\
					$puls_amplitude $puls_time\
					0V"
			}
			puts "$number_of_pulses x ($puls_amplitude $puls_time)"
			eval $pulsstring
			dac start $dac(number)
		}
	} else {
		set result(nextpuls) "0 0 0"
		set network_meas(nextpuls) "puls: off"
	}
}

proc readout_u_clamp {} {
	global result keithley;

	# Die Haltespannung auslesen
	if {[scan [kscan select $keithley(address) U_clamp] "%f" result(U_clamp)]==1} {
		if {$result(U_clamp) != "?"} {
# test the right value range of U_clamp
			if {$result(U_clamp)>-110 && $result(U_clamp)<110} {
				set result(U_clamp) [format "%0.5f" $result(U_clamp)]
			} else {
				set result(U_clamp) "?"
			}
		}
	} else {
		set result(U_clamp) "?"
	}
}

proc readout_nwa {} {
	global list result network_meas nwa;

	set result(nwa) ""

	set file_number [status read network_meas.s0]

	foreach ch $nwa(channels) {
		if {$list(network_meas:$ch:locked)} {
			# Auslesen des Netzwerkanalysators
			if {![file exists "$network_meas(prefix)/mw$ch[]_$network_meas(basename)"]} {
				file mkdir "$network_meas(prefix)/mw$ch[]_$network_meas(basename)"
			}
			set nwa_file_name "$network_meas(prefix)/mw$ch[]_$network_meas(basename)/mw$ch[]_$network_meas(basename).[format "%05d" $file_number]"
			nwa read $nwa(address) $ch $nwa_file_name
			if {$network_meas(recordspectrum)} {
				incr file_number
				status write network_meas.s0 $file_number
			}

			ieee write $nwa(address) "AUTO;"
		
			set fp [open $nwa_file_name a]
			puts $fp "U_clamp: $result(U_clamp) Volt"
			puts $fp "Bath-Therm: $result(temp1) Ohm"
			puts $fp "Cell-Therm: $result(temp2) Ohm"
			puts $fp "Cell-Pressure: $result(pressure) Volt (Gauge)"
			puts $fp "Cell-Pressure: $result(baratron) Volt (Baratron)"

			if {[info exists list(network_meas:nextpuls)]} {
				puts $fp $list(network_meas:nextpuls)
			} else {
				puts $fp "puls: off"
			}
			close $fp

# Jetzt die Resonanzkurve fitten:				
			catch {exec hpna -f $nwa_file_name}

			if {[file exists "$nwa_file_name[].fitpar"]} {
				set fitdata [open "$nwa_file_name[].fitpar"]
				set fitvals [gets $fitdata]
				if {[scan $fitvals "%*s %*s %f %f %f %f %f %f %f %f %f %f" \
				maxval maxval_err\
				maxfreq maxfreq_err\
				maxwidth maxwidth_err\
				offset offset_err\
				linear linear_err]!=10} {
					set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
					set maxval "?"
					set maxval_err "?"
					set maxfreq "?"
					set maxfreq_err "?"
					set maxwid "?"
					set maxwid_err "?"
					set offset "?"
					set offset_err "?"
					set linear "?"
					set linear_err "?"
					close $fitdata
			
					file delete "$nwa_file_name[].fitpar"
				} else {	
					close $fitdata
			
					file delete "$nwa_file_name[].fitpar"
				
					if {[expr $maxfreq/$maxwidth] < $network_meas(q_min) || [expr $maxfreq/$maxwidth] > $network_meas(q_max)} {	
						# falls die Gten einen bestimmten Wert bersteigt, den ganzen
						# Frequenzbereich nach der Resonanz absuchen
						ieee write $nwa(address) "CHAN$ch;S21;STAR$network_meas($ch:start);STOP$network_meas($ch:stop);POIN$nwa(numpoints);POWE$network_meas(power);"
						set list(network_meas:$ch:locked) 0
						set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
						set maxval "?"
						set maxval_err "?"
						set maxfreq "?"
						set maxfreq_err "?"
						set maxwid "?"
						set maxwid_err "?"
						set offset "?"
						set offset_err "?"
						set linear "?"
						set linear_err "?"
					} elseif {[expr $maxval<0.000001] || [expr log($maxval)/log(10)*20] < $network_meas(trans_min)} {	
						# falls das Resonanzsignal wieder verschwunden ist, den ganzen
						# Frequenzbereich absuchen
						ieee write $nwa(address) "CHAN$ch;S21;STAR$network_meas($ch:start);STOP$network_meas($ch:stop);POIN$nwa(numpoints);POWE$network_meas(power);"
						set list(network_meas:$ch:locked) 0
						set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
						set maxval "?"
						set maxval_err "?"
						set maxfreq "?"
						set maxfreq_err "?"
						set maxwid "?"
						set maxwid_err "?"
						set offset "?"
						set offset_err "?"
						set linear "?"
						set linear_err "?"
					} else {
						puts -nonewline "Q$ch = [format "%.1f" [expr $maxfreq/$maxwidth]]"
						puts -nonewline ", f$ch = [ValOut $maxfreq 8]Hz"
						puts -nonewline ", A$ch = [ValOut [expr log($maxval)/log(10)*20] 5]dB"
					
						if {$maxfreq > $network_meas($ch:start) && $maxfreq < $network_meas($ch:stop)} {
							ieee write $nwa(address) "SPAN$network_meas($ch:frequency_width);CENT$maxfreq;"
							
							if {$list(network_meas:$ch:firstspectrum) || \
							   	[expr log($maxval)/log(10)*20] < $network_meas(trans_min)} {
								set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
								set list(network_meas:$ch:firstspectrum) 0
							} else {
								set result(nwa) [format "$result(nwa)%0.5g %0.1e %0.0f %0.1e %0.0f %0.1e %0.5g %0.1e %0.5g %0.1e " \
									$maxval $maxval_err\
									$maxfreq $maxfreq_err\
									$maxwidth $maxwidth_err\
									$offset $offset_err\
									$linear $linear_err]
							}
						} else {
							# falls die Fitergebnisse ausserhalb der erlaubten Bereiche sind:
							set maxval "?"
							set maxval_err "?"
							set maxfreq "?"
							set maxfreq_err "?"
							set maxwid "?"
							set maxwid_err "?"
							set offset "?"
							set offset_err "?"
							set linear "?"
							set linear_err "?"
							
							set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
							puts "CH#$ch: frequency out of range!"
							ieee write $nwa(address) "CHAN$ch;S21;STAR$network_meas($ch:start);STOP$network_meas($ch:stop);POIN$nwa(numpoints);POWE$network_meas(power);"
							set list(network_meas:$ch:locked) 0
						}
					}
				}
			} else {
				# fr den Fall dass kein Fitparameter-File existiert:
				puts -nonewline "no fit resuls available"
				set maxval "?"
				set maxval_err "?"
				set maxfreq "?"
				set maxfreq_err "?"
				set maxwid "?"
				set maxwid_err "?"
				set offset "?"
				set offset_err "?"
				set linear "?"
				set linear_err "?"
				
				set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
			}
		puts ""
	#
	#	Ende gezoomtes Auslesen
	#
	#
		} else {
	#
	#
	#
	#
			set list(network_meas:nextpuls_result) "0 0 0"

			set maxval "?"
			set maxfreq "?"
			set markresult [ieee query $nwa(address) "CHAN$ch;POIN$nwa(numpoints_nolock);AUTO;MARK$ch;MARKMAXI;OUTPMARK;"]
			if {[scan $markresult "%f, %*f, %f" maxval maxfreq]==2} {
				if {[info exists maxval] && $maxval != "?"} {
					puts "Maximum CH$ch: $maxval dB (@ [ValOut $maxfreq]Hz)"
					if {$maxval>$network_meas(trans_max)} {
						set list(network_meas:$ch:locked) 1
						set list(network_meas:$ch:firstspectrum) 1
						set maxval "?"
					}
				}

				if {$maxval != "?"} {
					set maxval [expr exp($maxval/20*log(10))]
					if {$maxfreq != "?"} {
						set result(nwa) [format "$result(nwa)%0.5g ? %0.0f ? ? ? ? ? ? ? " $maxval $maxfreq ]
					} else {
						set result(nwa) [format "$result(nwa)%0.5g ? ? ? ? ? ? ? ? ? " $maxval ]
					}
				} else {
					set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
				}

				if {$list(network_meas:$ch:locked)} {
					scan [ieee query $nwa(address) "CHAN$ch;AUTO;MARK$ch;MARKMAXI;OUTPMARK;"] \
						"%f, %*f, %f" maxval maxfreq
					ieee write $nwa(address) "CENT$maxfreq;SPAN$network_meas($ch:frequency_width);"
					ieee write $nwa(address) "CHAN$ch;SING;AUTO"
				}
			}
		}

	}
		set list(network_meas:nextpuls) $network_meas(nextpuls)	
		set list(network_meas:nextpuls_result) $result(nextpuls)	
}

proc send_warning {} {
	global result;
	
	set fp [open "|mail eminus@localhost -s warning" w]
	puts $fp "[datestamp] $result(temp1) $result(temp2) $result(cap)"
	close $fp
}

proc print_actual_data {} {
	global result nwa network_meas list;

#
# line 1
#

	set firstval 1
		
	if {$result(silicon)!="?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "S: [ValOut $result(silicon)]Ohm"
	}
	
	if {$result(U_clamp) != "?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "U: [format "%.3f" $result(U_clamp)]V"
	}

	if {$result(coil_voltage) != "?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "cU: [ValOut $result(coil_voltage)]V"
	}
	
	if {$result(coil_current) != "?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts "cI: [ValOut $result(coil_current)]A"
	} else {
		puts ""
	}
	
#
# line 2
#
	
	set firstval 1
		
	if {$result(cap) != "?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "Level: [ValOut $result(cap) 5]F\
			([ValOut [expr 0.03*($result(cap)*1e12-16.7202)/(17.2436-16.7202)]]m)"
	}
	
	if {$result(temp1)!="?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "T_Bath: [ValOut $result(temp1)]Ohm"
	}
	
	if {$result(temp2)!="?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "T_Cell: [ValOut $result(temp2)]Ohm"
	} 

	set baratron(linear) 1.334449154
	set baratron(const) 0.022
	set pressure(linear) 35.225458256
	set pressure(const) 0.11023366
	source helium_vapor_pressure.tcl

	if {$result(pressure) != "?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		set pressure(val) [expr $pressure(linear)*$result(pressure)+$pressure(const)]
		if {$pressure(val)<13 & $result(baratron)!="?"} {
			set pressure(val) [expr $baratron(linear)*$result(baratron)+$baratron(const)]
		}
		set pressure(val) [expr 1e-3*$pressure(val)]
		puts "p: [ValOut $pressure(val)]bar"
	} else {
		if {$result(baratron)!="?"} {
			if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
			set pressure(val) [expr $baratron(linear)*$result(baratron)+$baratron(const)]
			set pressure(val) [expr 1e-3*$pressure(val)]
			puts "p = [ValOut $pressure(val)]bar"
		} else {
			set pressure(val) "?"
			puts ""
		}
	}

#
# line 3
#
	set firstval 1

	if {$pressure(val)!="?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "T(p): [ValOut [temp_from_vp_4He $pressure(val)*1e5]]K"
	}
	if {$result(fil_voltage)!="?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "Uf: [ValOut $result(fil_voltage)]V"
	}
	if {$result(fil_current)!="?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "If: [ValOut $result(fil_current)]A"
	}
	if {$result(fil_voltage)!="?" && $result(fil_current)!="?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "Rf: [ValOut [expr $result(fil_voltage) / $result(fil_current)]]Ohm"
	}

	if {$result(filament1) != "?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts -nonewline "F1: [ValOut $result(filament1)]Ohm"
	}

	if {$result(filament2) != "?"} {
		if {$firstval} { set firstval 0 } else { puts -nonewline ", " }
		puts "F2: [ValOut $result(filament2)]Ohm"
	} else {
		puts ""
	}


#
# output to data file
#
	if {[llength $nwa(channels)] == 1} {
		set result(nwa) "$result(nwa)[]? ? ? ? ? ? ? ? ? ? "
	}

	if {!$network_meas(nodataoutput)} {
		set fp [open "$network_meas(prefix)/mw$network_meas(basename)[].dat" "a"]	
		set result(text) "[datestamp] $result(temp1) $result(temp2)\
					$result(pressure) $result(baratron)\
					$result(filament1) $result(filament2)\
					$result(silicon) $result(U_clamp)\
					[string trim $result(nwa)] $network_meas(filament)\
					$result(cap) $list(network_meas:nextpuls_result) $network_meas(power)\
					[expr [lindex [ValIn $network_meas(1:frequency_width)] 0]/1e6]\
					[expr [lindex [ValIn $network_meas(2:frequency_width)] 0]/1e6]\
					$nwa(numpoints) $result(coil_current) $result(coil_voltage)\
					$result(fil_voltage) $result(fil_current)" 
					
		if {[file exists [Exp_Config_Dir]/flags/network_meas.new_section]} {
			file delete [Exp_Config_Dir]/flags/network_meas.new_section
			incr network_meas(section)
			rem "new section $network_meas(section)"
			puts $fp ""
		}
		
		
		puts $fp $result(text)
		close $fp
		
		if {[file exists [Exp_Config_Dir]/flags/network_meas.new_measurement]} {
			file delete [Exp_Config_Dir]/flags/network_meas.new_measurement

			# move the runlog-file to the actual data-directory
			set destfile "$network_meas(prefix)/mw$network_meas(basename).runlog"
			if {[file exists $destfile]} {
				puts "WARNING: destination runlogfile already exists!"
			} else {
				if {[file exists [Exp_Config_Dir]/run.log]} {
					file rename [Exp_Config_Dir]/run.log $destfile
				}
			}

			#increase the measurement number (month and number)
			set newmonth [clock format [clock seconds] -format "%y%m"]
			
			if {$network_meas(month) != $newmonth} {
				set network_meas(month) $newmonth
				set network_meas(number) 1
			} else {
				incr network_meas(number)
			}
			set network_meas(section) 0
			
			rem "new measurement $network_meas(section)"
		}
	}
}

proc void_nwadata {} {
	global result nwa
	set result(nwa) ""
	foreach ch $nwa(channels) {
		set result(nwa) "$result(nwa) ? ? ? ? ? ? ? ? ? ? "
	}
}

	init_measurement
	
	set result(filament1) "?"
	set result(filament2) "?"
	set result(silicon) "?"
	set result(cap) "?"
	set result(coil_current) "?"
	set result(coil_voltage) "?"

	prepare_tektronix
	
	trigger_nwa
	
	if {$network_meas(test_filament)} {
		switch_filament_to_ohmmeter	
		switch_to_filament1
	}

#	readout_old

	if {$network_meas(test_filament)} {
		readout_filament1
		switch_to_filament2
	}
	
	readout_pressure
	readout_capacity
	readout_filament_data
	readout_temperature
	readout_magnet_data

	pulse_filament
	
	if {$network_meas(test_filament)} {
		readout_filament2
	}
	switch_filament_to_pulsesource
	
	readout_silicon_resistance
	readout_u_clamp
	
	void_nwadata
	readout_nwa
	
	print_actual_data	
	writedata
